@@ -48,7 +48,7 @@
 sourceSlurm <- function(
   file,
   job_name    = NULL,
-  tmp_path    = tempdir(),
+  tmp_path    = opts_slurmR$get_tmp_path(),
   rscript_opt = list(vanilla = TRUE),
   plan        = "submit",
   ...
@@ -70,14 +70,14 @@ sourceSlurm <- function(
   if (!is.null(job_name))
     SBATCH$`job-name` <- job_name
   if (is.null(SBATCH$`job-name`) & is.null(job_name)) {
-    job_name          <- gsub(".+[/](?=[^/]+$)", "", file, perl=TRUE)
+    job_name          <- basename(file)
     SBATCH$`job-name` <- job_name
   }
   if (!is.null(SBATCH$`job-name`) & is.null(job_name))
     job_name <- SBATCH$`job-name`
 
-  file        <- normalizePath(file)
-  script_path <- sprintf("%s/%s.slurm", tmp_path, job_name)
+  file        <- basename(normalizePath(file))
+  script_path <- normalizePath(file.path(tmp_path, file))
 
   x <- new_bash(
     filename = script_path,
@@ -88,6 +88,9 @@ sourceSlurm <- function(
   SBATCH$`job-name` <- NULL # Already added
   x$add_SBATCH(SBATCH)
 
+  # Adding modules
+  x$append(opts_slurmR$get_preamble())
+
   # Finalizing by setting the R call
   x$Rscript(file = file, flags = rscript_opt)
 
@@ -112,8 +115,10 @@ sourceSlurm <- function(
 
   # Figuring out the plan
   plan <- the_plan(plan)
-  if (plan$collect)
+  if (plan$collect) {
     warning("When using Slurm via sourceSlurm, collection is not possible.", call. = FALSE)
+    plan <- the_plan("wait") # This is the closest
+  }
 
   # Submitting the job
   args <- c(
@@ -165,8 +170,9 @@ slurmr_cmd <- function(cmd_path, cmd_name = "slurmr", add_alias = TRUE, bashrc_p
 
   # Expanding path
   cmd_path <- normalizePath(cmd_path)
-  fn   <- suppressWarnings(sprintf("%s/%s", cmd_path, cmd_name))
+  fn   <- suppressWarnings(normalizePath(file.path(cmd_path, cmd_name)))
   bash <- new_bash(fn)
+  bash$append(opts_slurmR$get_preamble())
   bash$Rscript("", flags = list(vanilla = TRUE, e = "slurmR::sourceSlurm('$1', plan = 'submit')"))
   bash$write()
 
